@@ -95,6 +95,7 @@ Vue.component( 'foreign-key-field', {
         fetchDisplayValue: function () {
             if ( !this.$data._value ) {
                 this.displayValue = '(none)';
+                this.loading = false;
                 return;
             }
             this.loading = true;
@@ -901,6 +902,9 @@ var app = window.Yancy = new Vue({
 
         renderValue: function ( field, value ) {
             var schema = this.currentSchema;
+            if ( !schema.properties[ field ] ) {
+                return value;
+            }
             var fieldType = schema.properties[ field ].type;
             var type = Array.isArray( fieldType ) ? fieldType[0] : fieldType;
             if ( type == 'boolean' ) {
@@ -909,6 +913,13 @@ var app = window.Yancy = new Vue({
             return value;
         },
 
+        rowId: function ( row ) {
+            var schema = this.currentSchema,
+                idField = schema['x-id-field'] || 'id',
+                rowId = row[ idField ];
+            return rowId;
+        },
+
         rowViewUrl: function ( data ) {
             return this.fillUrl( this.currentSchema[ 'x-view-item-url' ], data );
         },
